******
djohno
******

djohno is a tiny app for checking over your error pages, and email
integration - to stop me doing evil things post-production to ensure
I've set up Sentry and my error pages by randomly breaking parts of my
site by editing code live.

Documentation is available at https://djohno.readthedocs.org.

Tests are run on Travis with every push - see
https://travis-ci.org/dominicrodger/djohno.

Release notes are available at
https://djohno.readthedocs.org/en/latest/release_notes.html.

Sneak Preview
=============

When installed, djohno looks a little bit like this:

.. image:: https://djohno.readthedocs.org/en/latest/_images/djohno.png
   :scale: 75%
   :alt: djohno's version view
